@@ -22,6 +22,7 @@ def parseOUTCAR(OUTCAR_in,foutlog):
         print("ERROR::file_not_found: "+OUTCAR_in)
         sys.exit()
     latt_list=[]
+    NIONS  = -1
     natoms = []
     elems = []
     zvals = []
@@ -44,19 +45,44 @@ def parseOUTCAR(OUTCAR_in,foutlog):
             latt_list=[]
             for i1 in range(3):
                 l1=fin.readline()
-                latt0=[ float(t1) for t1 in l1.split()[:3]]
-                latt_list.append(latt0)
+                latt0=[]
+                for t1 in l1.split()[:3]:
+                    for t2 in t1.split():
+                        if t2.rfind("-")>0:
+                            t3=float(t2[t2.rfind("-"):])
+                            latt0.append(t3)
+                            t3=t2[:t2.rfind("-")]
+                            if t3.rfind("-")>0:
+                                t4=float(t3[t3.rfind("-"):])
+                                latt0.append(t4)
+                                t4=float(t3[:t3.rfind("-")])
+                                latt0.append(t4)
+                            else:
+                                latt0.append(float(t3))
+                        else:
+                            t3=float(t2)
+                            latt0.append(t3)
+                latt_list.append(latt0[:3])
+        if "NIONS" in l1:
+            NIONS=int(l1.split("=")[-1].strip())
         if "ions per type" in l1:
-            natoms=[ int(t1) for t1 in l1.split("=")[-1].split()]
+            natstr1=l1.split("=")[-1].strip()
+            natoms=[ int(t1) for t1 in natstr1.split()]
+            if sum(natoms)!=NIONS:
+                if len(natstr1)%4!=0:
+                    iadd1=4-len(natstr1)%4
+                    natstr1=iadd1*"0"+natstr1
+                natoms=[ int(natstr1[i1:i1+4]) for i1 in range(0,len(natstr1),4)]
         if "ZVAL" in l1 and l1.find("ZVAL")<10:
             zvals=[ float(t1) for t1 in l1.split("=")[-1].split()]
         if "NELECT" in l1:
             NELECT=float(l1.split()[2])
-        if "position of ions in fractional coordinates (direct lattice)" in l1:
+        if "POSITION" in l1 and "TOTAL-FORCE" in l1:
             posi_list=[]
+            l1=fin.readline()
             for i1 in range(sum(natoms)):
                 l1=fin.readline()
-                p2=[ float(t1) for t1 in l1.split()]
+                p2=[ float(t1) for t1 in l1.split()[:3]]
                 posi_list.append(p2)
         if "average (electrostatic) potential at core" in l1:
             l1=fin.readline()
@@ -66,7 +92,10 @@ def parseOUTCAR(OUTCAR_in,foutlog):
                 pots_list=[]
             while n1<sum(natoms):
                 l1=fin.readline()
-                l2=l1.split()[1::2]
+                l2=[]
+                for t2 in l1.split():
+                    if "-" in t2:
+                        l2.append(float(t2[t2.find("-"):]))
                 for t2 in l2:
                     n1+=1
                     pots_list.append(float(t2))
@@ -78,6 +107,11 @@ def parseOUTCAR(OUTCAR_in,foutlog):
     if len(pots_list)!=sum(natoms):
         print("Error: missing electrostatic potentials in the OUTCAR")
         sys.exit()
+    posi_list2=[]
+    latt_inv=np.linalg.inv(latt_list)
+    for p1 in posi_list:
+        p2=np.dot(p1,latt_inv)
+        posi_list2.append(p2)
     ######################
     tstr="  elements = "
     for e1 in elems:
@@ -98,7 +132,7 @@ def parseOUTCAR(OUTCAR_in,foutlog):
     foutlog.write(tstr)
     foutlog.flush()
     ######################
-    return (np.array(latt_list),natoms,elems,posi_list,pots_list,charge_cell)
+    return (np.array(latt_list),natoms,elems,posi_list2,pots_list,charge_cell)
 
 class Ewpot_real:
     def __init__(self,latt_vect_in,dielectric_tensor_in,NumEwReal_in,foutlog):
@@ -440,6 +474,7 @@ def calcEdefCorrectionVASP():
     # readingOUTCAR
     (latt_bulk,natoms_bulk,elems_bulk,posi_bulk,pot_bulk,qcell_bulk)=parseOUTCAR(pathOUTCAR_bulk,foutlog)
     (latt_def,natoms_def,elems_def,posi_def,pot_def,qcell_def)=parseOUTCAR(pathOUTCAR_defect,foutlog)
+    # sys.exit()
     foutlog.write(50*"="+"\n")
     # check lattice
     for i1 in range(3):
@@ -590,7 +625,6 @@ def calcEdefCorrectionVASP():
     foutlog.flush()
     ##### rdist from defect
     rdist=[]
-    rmax=0.0
     for ip2,p2 in enumerate(posi_def):
         if potdiff[ip2]==None:
             rdist.append(0.0)
@@ -609,10 +643,8 @@ def calcEdefCorrectionVASP():
                         if rdiff2<rdiff2min:
                             rdiff2min=rdiff2
                             pdiff3min=copy.copy(pdiff3)
-            if rdiff2>rmax:
-                rmax=rdiff2min
             rdist.append(rdiff2min)
-    
+    rmax=np.max(rdist)
 
     #### calc point-charge potential and energy
     Ewald_real_Nmax=3
@@ -675,7 +707,7 @@ def calcEdefCorrectionVASP():
                         if rdiff2<rdiff2min:
                             rdiff2min=rdiff2
                             pdiff3min=copy.copy(pdiff3)
-            relvect=np.dot(latt_def,pdiff3min)
+            relvect=np.dot(pdiff3min,latt_def)
             r_relvect=np.linalg.norm(relvect)
             if r_relvect<1e-10:
                 flag_defsite=True
@@ -697,7 +729,7 @@ def calcEdefCorrectionVASP():
                     if rdiff2<rdiff2min:
                         rdiff2min=rdiff2
                         pdiff3min=copy.copy(pdiff3)
-        relvect=np.dot(latt_def,pdiff3min)
+        relvect=np.dot(pdiff3min,latt_def)
         r_relvect=np.linalg.norm(relvect)
         pot_real=epot_real.calcpot_atom(relvect)
         pot_recip=epot_recip.calcpot_atom(relvect)
