@@ -22,9 +22,12 @@ class EquilibriumConditions:
             bool_silent_chempotcalc=False
         else:
             bool_silent_chempotcalc=True
+        fout1=open(root_outfiles+"_loading_messages.txt","w")
+        fout1.write("-"*100+"\n")
         print(" Reading equilibrium conditions (eq)")
-        fnout=root_outfiles+"_parameters_temp_gasP.csv"
-        fout_tp=open(fnout,"w")
+        fout1.write(" Reading equilibrium conditions (eq)\n")
+        # fnout=root_outfiles+"_parameters_temp_gasP.csv"
+        # fout_tp=open(fnout,"w")
         ### constructing conditions
         temperatures_list=[]
         if "temperature" in input_params:
@@ -52,10 +55,15 @@ class EquilibriumConditions:
             str1="   Temperatures: "
             str_out="Temperatures,"
             for t1 in temperatures_list:
-                str1+=f"{t1}, "
+                if len(str1)>90:
+                    print(str1)
+                    fout1.write(str1+"\n")
+                    str1=17*" "
+                str1+=f"{t1:7.2f}, "
                 str_out+=f"{t1}, "
             print(str1[:-2])
-            fout_tp.write(str_out[:-2]+"\n")
+            fout1.write(str1[:-2]+"\n")
+            # fout_tp.write(str_out[:-2]+"\n")
         else:
             print(" ERROR(eq.temperature):: missed temperature")
             sys.exit()
@@ -92,15 +100,18 @@ class EquilibriumConditions:
                     cpinit2=params2["chempot_init"]
                 else:
                     print(" ERROR(eq.fix_Natoms):: missed chempot_init for "+e2)
+                    print("   If this block isn't used, please comment out.")
                     sys.exit()
                 if len(nat2_array)>0:
                     self.Natoms_list.append(np.array(nat2_array))
                 else:
                     if nat2_num==0:
                         print(" ERROR(eq.fix_Natoms):: missed numCell_num for "+e2)
+                        print("   If this block isn't used, please comment out.")
                         sys.exit()
                     if nat2_min=="NONE":
                         print(" ERROR(eq.fix_Natoms):: missed numCell_start for "+e2)
+                        print("   If this block isn't used, please comment out.")
                         sys.exit()
                     if nat2_max=="NONE":
                         nat2_max=nat2_min
@@ -116,6 +127,7 @@ class EquilibriumConditions:
                 for n1 in self.Natoms_list[ie1]:
                     str1+=f"{n1}, "
                 print(str1[:-2])
+                fout1.write(str1[:-2]+"\n")
         self.Natoms_linking = False
         self.Natoms_cp_scheme = "fix"
         if "fix_Natoms_params" in input_params:
@@ -123,6 +135,53 @@ class EquilibriumConditions:
             if "linking_multiple" in params1:
                 self.Natoms_linking = params1["linking_multiple"]
         ###############################################
+        ### Reading espots (electrostatic potentials)
+        self.espots_list=[]
+        self.espots_charges={}
+        if "espots" in input_params:
+            params1=input_params["espots"]
+            pot2_start="NONE"
+            pot2_end="NONE"
+            pot2_num=0
+            if "potV_start" in params1:
+                pot2_start=float(params1["potV_start"])
+            if "potV_end" in params1:
+                pot2_end=float(params1["potV_end"])
+            if "potV_num" in params1:
+                pot2_num=params1["potV_num"]
+            if "charges" in params1:
+                self.espots_charges=params1["charges"]
+            if pot2_start=="NONE":
+                print("   ERROR(eq.eqpots):: missed potV_start")
+                print("     If this function isn't used, please comment out.")
+                sys.exit()
+            if pot2_end=="NONE":
+                pot2_end=pot2_start
+                print("   WARNING(eq.espots):: potV_num is forced to 1.")
+                fout1.write("   WARNING(eq.espots):: potV_num is forced to 1.\n")
+                pot2_num=1
+            if pot2_num==0:
+                print("   ERROR(eq.espots):: missed potV_num")
+                print("     If this function isn't used, please comment out.")
+                sys.exit()
+            if len(self.espots_charges)==0:
+                print("   ERROR(eq.espots):: missed espots.charges")
+                print("     Please give (effective) charge values of ions and electrons.")
+                print("     If this function isn't used, please comment out.")
+                sys.exit()
+            self.espots_list=np.linspace(pot2_start,pot2_end,pot2_num)
+        if len(self.espots_list)!=0:
+            str1=f"   espots: "
+            for e1 in self.espots_list:
+                str1+=f"{e1}, "
+            print(str1[:-2])
+            fout1.write(str1[:-2]+"\n")
+            str1=f"   espots-charges:\n"
+            for k1,c1 in self.espots_charges.items():
+                str1+=f"      {k1} = {c1}\n"
+            print(str1[:-1])
+            fout1.write(str1)
+        ###############################################
         self.elements_fix_chempots=[]
         self.chempots_list=[]
         cond_fixchempots_list=[]
@@ -147,7 +206,9 @@ class EquilibriumConditions:
                 str1+=f"{e1}, "
             print(str1[:-2])
             print("-"*50)
-            refPhase=ReferencePhases(self.elements_fix_chempots,input_paths)
+            fout1.write(str1[:-2]+"\n")
+            fout1.write("-"*50+"\n")
+            refPhase=ReferencePhases(self.elements_fix_chempots,input_paths,fout1)
             if not "eq_phases" in params1:
                 print(" ERROR(eq.fix_chempots.eq_phases):: missed")
                 sys.exit()
@@ -182,6 +243,7 @@ class EquilibriumConditions:
                         print(f" ERROR(eq.fix_chempots):: phase not found: {ph1}")
                         sys.exit()
                 print(str1[:-2])
+                fout1.write(str1[:-2]+"\n")
                 if len(ph_list)!=len(self.elements_fix_chempots):
                     print(f" ERROR(eq.fix_chempots):: #eq_phases({l1}) is not equal to #elements(fix_chempots)")
                     sys.exit()
@@ -228,13 +290,19 @@ class EquilibriumConditions:
                         else:
                             gas_pressures[l1]=np.linspace(pmin,pmax,pnum)
             for l1,p1_list in gas_pressures.items():
-                str1=f"   Pressures ({l1}): "
+                str1=f"   Pressures({l1}): "
+                len_head1=len(str1)
                 str_out=f"Pressures_{l1}, "
                 for p1 in p1_list:
-                    str1+=f"{p1:7.1e}, "
-                    str_out+=f"{p1:20.15f}, "
+                    str_out+=f"{p1:16.10e}, "
+                    if len(str1)>90:
+                        print(str1)
+                        fout1.write(str1+"\n")
+                        str1=len_head1*" "
+                    str1+=f"{p1:8.2e}, "
                 print(str1[:-2])
-                fout_tp.write(str_out[:-2]+"\n")
+                fout1.write(str1[:-2]+"\n")
+                # fout_tp.write(str_out[:-2]+"\n")
             if len(temperatures_list)==0:
                 temp_press_prodlist=["NONE"]
                 temp_press_params=[]
@@ -255,7 +323,7 @@ class EquilibriumConditions:
                 for it2,t2 in enumerate(t1):
                     d1[temp_press_params[it2]]=t2
                 temp_press_list.append(d1)
-            fout_tp.close()
+            # fout_tp.close()
             #### Constructing lambda-list
             lambda_list=[]
             if len(phases_limits)==1:
@@ -280,18 +348,18 @@ class EquilibriumConditions:
                         d1[lambda_params[it2]]=lam2
                     lambda_list.append(d1)
             if len(phases_limits)>0:
-                fnout_lam=root_outfiles+"_parameters_lambda.csv"
-                fout_lam=open(fnout_lam,"w")
+                # fnout_lam=root_outfiles+"_parameters_lambda.csv"
+                # fout_lam=open(fnout_lam,"w")
                 str_out=""
                 for l1 in lambda_list[0].keys():
                     str_out+=f"{l1:^20s}, "
-                fout_lam.write(str_out[:-2]+"\n")
+                # fout_lam.write(str_out[:-2]+"\n")
                 for lam1 in lambda_list:
                     str_out=""
                     for l1,v1 in lam1.items():
                         str_out+=f"{v1:20.15f}, "
-                    fout_lam.write(str_out[:-2]+"\n")
-                fout_lam.close()
+                    # fout_lam.write(str_out[:-2]+"\n")
+                # fout_lam.close()
             def make_ph_list(phlist_in):
                 phlist_out=[]
                 for ph1 in phlist_in:
@@ -331,12 +399,12 @@ class EquilibriumConditions:
         ### Constructing fix-Natoms!!!
         Natoms_target_prod_list=[]
         if len(self.elements_fix_Natoms)>0:
-            fnout=root_outfiles+"_parameters_fixNatoms.csv"
-            fout_nat=open(fnout,"w")
+            # fnout=root_outfiles+"_parameters_fixNatoms.csv"
+            # fout_nat=open(fnout,"w")
             str1=""
             for ie1,e1 in enumerate(self.elements_fix_Natoms):
                 str1+=f"{e1} , "
-            fout_nat.write(str1[:-2]+"\n")
+            # fout_nat.write(str1[:-2]+"\n")
             if len(self.elements_fix_Natoms)==1:
                 Natoms_target_prod_list=[[t1] for t1 in self.Natoms_list[0]]
             else:
@@ -362,10 +430,29 @@ class EquilibriumConditions:
                 str1=""
                 for n1 in nlist1:
                     str1+=f"{n1} , "
-                fout_nat.write(str1[:-2]+"\n")
-            fout_nat.close()
+                # fout_nat.write(str1[:-2]+"\n")
+            # fout_nat.close()
         #################################################
-        ### Combining the parameters of fix-chempots and fix-Natoms!!!
+        ### Combining the parameters of fix-chempots and espots
+        if len(self.espots_list)!=0:
+            cond_fixchempots_list_espots=[]
+            for c1 in cond_fixchempots_list:
+                for espot1 in self.espots_list:
+                    c2={}
+                    for k1,v1 in c1.items():
+                        if "chempot_" in k1:
+                            elem1=k1.split("_")[1]
+                            v2=v1
+                            if elem1 in self.espots_charges.keys():
+                                v2+=self.espots_charges[elem1]*espot1
+                            c2[k1]=v2
+                        else:
+                            c2[k1]=v1
+                    c2["espot"]=espot1
+                    cond_fixchempots_list_espots.append(c2)
+            cond_fixchempots_list=cond_fixchempots_list_espots
+        #################################################
+        ### Combining the parameters of fix-chempots and fix-Natoms
         self.eq_conditions=[]
         if len(self.elements_fix_Natoms)==0:
             self.eq_conditions=cond_fixchempots_list
@@ -388,6 +475,8 @@ class EquilibriumConditions:
                     cond2.update(cond1)
                     self.eq_conditions.append(cond2)
         print("-"*100)
+        fout1.write("-"*100+"\n")
+        fout1.close()
         self.id_cond=0
 
     def __iter__(self):
