@@ -43,7 +43,6 @@ class ReferencePhases:
         if self.phase_host=="":
             print(" WARNING::host-tag not-found (inpydecs_phases.csv): solid*")
             return False
-        print("   Host-composition: "+self.phase_host["composition"])
         return True
 
 #    def get_host_composition(self):
@@ -73,11 +72,12 @@ class ReferencePhases:
             finterp=interpolate.interp1d(xlist,ylist,kind="cubic")
             ph1["delG_finterp"]=finterp
 
-    def parse_phases(self,filename_phases_in="inpydecs_phases.csv",elemsList_in="host"):
+    def parse_phases(self,filename_phases_in="inpydecs_phases.csv",elemsList_in="host",fout_lm=None):
         if not os.path.exists(filename_phases_in):
             print(" ERROR::file_not_found: "+filename_phases_in)
             sys.exit()
         print(" Reading file: "+filename_phases_in)
+        fout_lm.write(" Reading file: "+filename_phases_in+"\n")
         fin=open(filename_phases_in).readlines()
         columns=[ t1.strip() for t1 in fin[0].split(",")]
         column_names=set(["commentout","type","composition","energy_0K","filename_delG"])
@@ -110,6 +110,7 @@ class ReferencePhases:
             if len(ph0["commentout"])==0 and len(ph0["composition"])>0:
                 if not ph0["type"] in ["gas","solid","solid*"]:
                    print(" WARNING::invalid type: "+(l3))
+                   fout_lm.write(" WARNING::invalid type: "+(l3)+"\n")
                 ph0["energy_0K"]=float(ph0["energy_0K"])
                 phaseList0.append(ph0)
         self.check_host(phaseList0)
@@ -119,19 +120,40 @@ class ReferencePhases:
             slected_elems=comp_host_elems
         else:
             slected_elems=set(elemsList_in)
+        print("   Host-composition: "+self.phase_host["composition"])
+        fout_lm.write("   Host-composition: "+self.phase_host["composition"]+"\n")
         phaseList1=[]
+        str1_solid="   Solid-list: "
+        str1_gas="   Gas-list: "
         for ph1 in phaseList0:
             comp1_elems=set(ph1["composition_dict"].keys())
             elems_sum=slected_elems.union(comp1_elems)
             if len(elems_sum)<=len(slected_elems):
                 phaseList1.append(ph1)
+            if ph1["type"]=="solid":
+                str1_solid+=f"{ph1['composition']}, "
+            if ph1["type"]=="gas":
+                str1_gas+=f"{ph1['composition']}, "
+        if str1_solid[-2]==":":
+            print(f"{str1_solid} None")
+            fout_lm.write(f"{str1_solid} None\n")
+        else:
+            print(f"{str1_solid[:-2]}")
+            fout_lm.write(f"{str1_solid[:-2]}\n")
+        if str1_gas[-2]==":":
+            print(f"{str1_gas} None")
+            fout_lm.write(f"{str1_gas} None\n")
+        else:
+            print(f"{str1_gas[:-2]}")
+            fout_lm.write(f"{str1_gas[:-2]}\n")
         self.phaseList=phaseList1
         print("-"*50)
+        fout_lm.write("-"*50+"\n")
 
     def get_phaseList(self):
         return self.phaseList
 
-    def __init__(self,elemsList_in="host",input_paths=["./"]):
+    def __init__(self,elemsList_in="host",input_paths=["./"],fout_lm=None):
         fnin="NONE"
         for path1 in input_paths:
             if os.path.exists(path1+"inpydecs_phases.csv"):
@@ -144,7 +166,7 @@ class ReferencePhases:
             self.filename_root=fnin[:fnin.rfind("/")+1]
         else:
             self.filename_root=""
-        self.parse_phases(fnin,elemsList_in)
+        self.parse_phases(fnin,elemsList_in,fout_lm)
 
     def get_phasedata(self,comp_in):
         ph_target="NONE"
