@@ -153,8 +153,12 @@ class DefectEqSolver:
                                     res_eF0+2.0*opt_params_in["opt_eFermi_edel"])
             res_qtot=self.calc_defEne_single(temperature_in,chempots_in,res_eF)
         elif opt_params_in["opt_eFermi_type"]=="root_scalar":
-            res_eF=optimize.root_scalar(func_eFermi_local,bracket=[opt_params_in["opt_eFermi_emin"],
+            try:
+                res_eF=optimize.root_scalar(func_eFermi_local,bracket=[opt_params_in["opt_eFermi_emin"],
                             opt_params_in["opt_eFermi_emax"]],method="ridder")
+            except ValueError:
+                print(" WARNING(opt_eFermi):: Failed to find Fermi level satisfying chage neutrality condition.")
+                return(None,None)
             #res_eF=optimize.root_scalar(func_eFermi_local,bracket=[opt_params_in["opt_eFermi_emin"],
             #                opt_params_in["opt_eFermi_emax"]],method="brenth")
             res_eF=res_eF.root
@@ -269,8 +273,9 @@ class DefectEqSolver:
             while residualRMS_Nsites>opt_params_in["opt_Nsites_tol"] and i_loop<opt_params_in["opt_Nsites_maxloop"]:
                 (res_eF,res_qtot)=self.opt_eFermi_for_chempots(temperature_in,chempots_in,opt_params_in,root_outfiles)
                 if self.defects.check_minus_defect_energy():
-                    print(" ERROR(opt_Nsites):: Densities cannot be obtained for minus defect formation energy.")
-                    print("   Check output-files: *_Edef_eFermi.*  ")
+                    print(" ERROR(opt_Nsites):: Densities cannot be obtained for minus defect formation energies.")
+                    print("    You can check the case by using 'just_plot_Edef = True' in the input file (inpydecs.toml).")
+                    # print("   Check output-files: *_Edef_eFermi.*  ")
                     return None
                 self.update_Nsites_defective()
                 Nsites_new=self.host.get_Nsites_defective()
@@ -281,9 +286,9 @@ class DefectEqSolver:
                 i_loop+=1
             if i_loop==opt_params_in["opt_Nsites_maxloop"]:
                 print(" WARNING(opt_Nsites):: Nsites_loop reaches maxloop:"+str(i_loop))
-        fnout_csv=root_outfiles+"_defect_densities.csv"
         data_defect_densities=self.produce_outheader_density(temperature_in,chempots_in,res_eF,res_qtot,self.host.get_Egap(),self.host.get_Volume())
-        self.output_density_data(data_defect_densities,fnout_csv)
+        # fnout_csv=root_outfiles+"_defect_densities.csv"
+        # self.output_density_data(data_defect_densities,fnout_csv)
         if opt_params_in["opt_Nsites_output_Edef_atlast"]:
             self.output_defEne_wrt_eFermi(temperature_in,chempots_in,root_outfiles,plot_params_in)
             self.calc_defEne_single(temperature_in,chempots_in,res_eF)
@@ -293,19 +298,19 @@ class DefectEqSolver:
             fout1.close()
         return data_defect_densities
 
-    def output_density_data(self,data_in,out_filename):
-        fout=open(out_filename,"w")
-        for i1 in range(len(data_in[0])):
-            str1=""
-            for d1 in data_in:
-                str1+=str(d1[i1])+","
-            fout.write(str1[:-1]+"\n")
-        fout.close()
-        return
+    #def output_density_data(self,data_in,out_filename):
+    #    fout=open(out_filename,"w")
+    #    for i1 in range(len(data_in[0])):
+    #        str1=""
+    #        for d1 in data_in:
+    #            str1+=str(d1[i1])+","
+    #        fout.write(str1[:-1]+"\n")
+    #    fout.close()
+    #    return
 
     def produce_outheader_density(self,temperature_in,chempots_in,eFermi_in,qtot_in,Egap,Vol):
         outdata_all=[]
-        outdata_all.append([" Egap = "+str(Egap),"line_color","line_style","line_width","parameter","value"])
+        outdata_all.append([" Egap = "+str(Egap),"line_color","line_style","line_width","condition","this_dir"])
         outdata_all.append([" Volume = "+str(Vol),"","","","temperature",temperature_in])
         (Natoms_def,Natoms_host)= self.defects.calc_Natoms()
         elems_list=[]
@@ -615,9 +620,9 @@ class DefectEqSolver:
             fout1.close()
         return out_defect_densities
 
-    def __init__(self,input_params_host,elements_in,input_paths_in):
-        self.host=Host(input_params_host,input_paths_in)
-        self.defects=Defects(self.host,elements_in,input_paths_in)
+    def __init__(self,input_params_host,elements_in,input_paths_in,densform_in,root_outfiles):
+        self.host=Host(input_params_host,input_paths_in,root_outfiles)
+        self.defects=Defects(self.host,elements_in,input_paths_in,densform_in,root_outfiles)
         self.reset_id_loop_Nsites()
         self.reset_id_loop_eFermi()
         self.chempots_fixNatoms="NONE"
@@ -632,6 +637,9 @@ class DefectEqSolver:
             if "chempot_" in l1:
                 e1=l1.split("_")[1].strip()
                 chempots[e1]=v1
+        if "espot" in eq_cond_in.keys():
+            self.host.set_espot(eq_cond_in["espot"])
+            self.defects.set_espot(eq_cond_in["espot"])
         if not "just_plot_Edef" in solver_params_in:
             solver_params_in["just_plot_Edef"]=False
         if solver_params_in["just_plot_Edef"]:
